@@ -1,4 +1,4 @@
-from main_log import *
+from .main_log import *
 
 __all__ = ['MainLog', ]
 
