@@ -153,7 +153,7 @@ class BaseLog:
         logging.getLogger(self.program_log_name).error(message, *args, **kwargs)
 
     def trace(self, *args, **kwargs):
-        message = self.trace_model('TRACE', kwargs)
+        message = self.trace_model('TRACE', kwargs.get('extra'))
         logging.getLogger(self.job_log_name).debug(message, *args, **kwargs)
 
     def external_log(self,
